Learn R Programming

proxirr (version 0.5)

.gamma: Calculate Gamma of Irreplaceability

Description

This function calculates Gamma of Irreplaceability from a vector of Alpha Irreplaceability values. Alpha Irreplaceability values can be calculated using .alpha().

Usage

.gamma(alphas, na.rm = FALSE)

Value

A non-negative number.

Arguments

alphas

vector - A vector of numbers between 0-1.

na.rm

logical - Should missing values (NA) be removed?

Author

Daniele Baisero, daniele.baisero@gmail.com

Details

Gamma of Irreplaceability is not a true irreplaceability metric, but allows for ranking between sites better than Beta. It is a non-negative number where the integer component represents the number of species for whom the site is wholly irreplaceable (Alpha=1) plus a decimal component calculated as a Beta calculated on all species for whom the site is not irreplaceable (Alpha<1).

References

tools:::Rd_expr_doi("10.1111/cobi.13806")

Examples

Run this code
.gamma(alphas=c(0.1,0.32,0.5))
.gamma(alphas=c(0.1,0.32,0.9))
.gamma(alphas=c(0.1,0.32,1))
.gamma(alphas=c(0.1,0.32,1,1))
.gamma(alphas=c(0.1,0.32,NA), na.rm=TRUE)

Run the code above in your browser using DataLab