Given a valid Marxan input.dat file, it returns a copy of the PUVSPRNAME file (puvspr.dat), with additional columns containing the feature's global value, target value, and alpha irreplaceability.
marxan_alphas(input, triage = FALSE)A data.frame
string - The address of the input.dat file.
logical - Should features with unachievable targets be given an
irreplaceability of 0? See alpha.
Daniele Baisero, daniele.baisero@gmail.com
The global value is obtained as the sum of the feature's "amount" column in PUVSPRNAME.
The target value is obtained from the SPECNAME file (spec.dat), either as the proportion of the global value (if the "prop" column is present in SPECNAME), or as the "target" value in SPECNAME (otherwise). This behaviour mirrors Marxan's default behaviour.