Learn R Programming

proxirr (version 0.5)

marxan_run: Marxan: Save Alpha, Beta and Gamma Irreplaceabilities

Description

Saves the outputs of marxan_alphas, marxan_betas, and marxan_gammas in the marxan output folder.

Usage

marxan_run(input, alphas = TRUE, betas = TRUE, gammas = TRUE, triage = FALSE)

Value

TRUE

Arguments

input

string - The address of the input.dat file.

alphas

logical - Should the Alpha Irreplaceability output be saved?

betas

logical - Should the Beta Irreplaceability output be saved?

gammas

logical - Should the Gamma of Irreplaceability output be saved?

triage

logical - Should features with unachievable targets be given an irreplaceability of 0? See alpha, beta and beta.

Author

Daniele Baisero, daniele.baisero@gmail.com

Details

Three files ('_proxirr_alphas.csv', '_proxirr_betas.csv', '_proxirr_gammas.csv') will be created prefixed with the scenario name indicated in 'input.dat' ('SCENNAME').