This function calculates Gamma of Irreplaceability from a vector of Alpha
Irreplaceability values. Alpha Irreplaceability values can be calculated using
.alpha().
Gamma of Irreplaceability is not a true irreplaceability metric, but allows
for ranking between sites better than Beta. It is a non-negative number where
the integer component represents the number of species for whom the site is
wholly irreplaceable (Alpha=1) plus a decimal component calculated as a Beta
calculated on all species for whom the site is not irreplaceable (Alpha<1).